coalib.settings package
=======================

Submodules
----------

coalib.settings.Annotations module
----------------------------------

.. automodule:: coalib.settings.Annotations
    :members:
    :undoc-members:
    :show-inheritance:

coalib.settings.ConfigurationGathering module
---------------------------------------------

.. automodule:: coalib.settings.ConfigurationGathering
    :members:
    :undoc-members:
    :show-inheritance:

coalib.settings.DocstringMetadata module
----------------------------------------

.. automodule:: coalib.settings.DocstringMetadata
    :members:
    :undoc-members:
    :show-inheritance:

coalib.settings.FunctionMetadata module
---------------------------------------

.. automodule:: coalib.settings.FunctionMetadata
    :members:
    :undoc-members:
    :show-inheritance:

coalib.settings.Section module
------------------------------

.. automodule:: coalib.settings.Section
    :members:
    :undoc-members:
    :show-inheritance:

coalib.settings.SectionFilling module
-------------------------------------

.. automodule:: coalib.settings.SectionFilling
    :members:
    :undoc-members:
    :show-inheritance:

coalib.settings.Setting module
------------------------------

.. automodule:: coalib.settings.Setting
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: coalib.settings
    :members:
    :undoc-members:
    :show-inheritance:
